import logging
from functools import wraps

class Error(Exception):
    """Base class for exceptions in this module."""
    pass

class ApiError(Error):
    def __init__(self, request_url, response_code):
        self.request = request_url
        self.response_code = response_code

class ApiInvalidResponseError(Error):
    pass

class ConnectionTimeoutError(Error):
    pass

def exception_handler(fn):
    @wraps(fn)
    def wrapper(*args, **kwargs):
        try:
            fn(*args, **kwargs)
        except Error:
            logger = logging.getLogger('')
            logger.exception("Internal error occur")
    return wrapper

